@@ -1,10 +1,41 @@
 from sqlalchemy.orm import defer
+from sqlalchemy.orm.collections import InstrumentedList
 from sqlalchemy.orm.mapper import Mapper
 from sqlalchemy.orm.query import _ColumnEntity
 from sqlalchemy.orm.properties import ColumnProperty
 from sqlalchemy.sql.expression import desc, asc
 
 
+class SmartList(InstrumentedList):
+    def has(self, attr):
+        """
+        Returns True if any member of this collection has given attribute
+        defined.
+
+        Example syntax:
+
+            >>> Category.articles.has('name')
+
+        :param attr: collection member attribute name
+        """
+        adapter = self._sa_adapter
+        owner_class = adapter.owner_state.class_
+        relation = getattr(owner_class, adapter._key).property
+        relation_class = relation.mapper.class_
+
+        if not hasattr(relation_class, attr):
+            raise AttributeError(
+                'Class %s does not have attribute named %s' %
+                (relation_class.__name__, attr)
+            )
+
+        for record in self:
+            if getattr(record, attr):
+                return True
+
+        return False
+
+
 def sort_query(query, sort):
     """
     Applies an sql ORDER BY for given query. This function can be easily used
@@ -16,7 +47,7 @@ def sort_query(query, sort):
         >>> from sqlalchemy import create_engine
         >>> from sqlalchemy.orm import sessionmaker
         >>> from sqlalchemy.ext.declarative import declarative_base
-        >>> from sqlalchemy_utils import escape_like, sort_query
+        >>> from sqlalchemy_utils import sort_query
         >>>
         >>>
         >>> engine = create_engine(
